"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validatePrivateKey = exports.createSignature = void 0;
const openpgp = require("openpgp");
const errors_1 = require("./errors");
const pgpPrivateKeyBeginBlock = '-----BEGIN PGP PRIVATE KEY BLOCK-----\n';
const pgpPrivateKeyEndBlock = '-----END PGP PRIVATE KEY BLOCK-----';
async function createSignature(options) {
    validatePrivateKey(options.privateKey);
    const privateKey = await openpgp.decryptKey({
        privateKey: await openpgp.readPrivateKey({
            armoredKey: options.privateKey.armoredKey,
        }),
        passphrase: options.privateKey.passphrase,
    });
    const message = await openpgp.createMessage({ text: options.messageRaw });
    const detachedSignature = await openpgp.sign({
        message,
        signingKeys: privateKey,
        detached: true,
    });
    return Promise.resolve(detachedSignature.replace(/\r\n/g, '\n').trim());
}
exports.createSignature = createSignature;
function validatePrivateKey(pgpPrivateKey) {
    const armoredKey = pgpPrivateKey.armoredKey.trim();
    if (!armoredKey.startsWith(pgpPrivateKeyBeginBlock)) {
        throw new errors_1.PgpPrivateKeyValidationError('missing BEGIN PGP PRIVATE KEY BLOCK');
    }
    if (!armoredKey.endsWith(pgpPrivateKeyEndBlock)) {
        throw new errors_1.PgpPrivateKeyValidationError('missing END PGP PRIVATE KEY BLOCK');
    }
}
exports.validatePrivateKey = validatePrivateKey;
//# sourceMappingURL=sign.js.map